@@ -13,7 +13,7 @@ flag=False
 for i in range(10):
 	tempStr='/'.join(['..' for i in range(i)])
 	path=os.path.abspath(os.path.join(os.getcwd(),tempStr))
-	if os.path.exists(path+'/Common') and os.path.exists(path+'/Common/__init__.py'):
+	if os.path.exists(path+'/Common') and os.path.exists(path+'/Common/__common__.py'):
 		flag=True
 		break
 
